shouldUseDynamicLibraryProcess top-level property
if a library path is set to this value, the DynamicLibrary shoudl be
loaded with DynamicLibrary.process()
Implementation
String shouldUseDynamicLibraryProcess = "DynamicLibrary.process();";
if a library path is set to this value, the DynamicLibrary shoudl be
loaded with DynamicLibrary.process()
String shouldUseDynamicLibraryProcess = "DynamicLibrary.process();";